@@ -354,9 +354,21 @@ def xhr_save_product(request, pk=None, type=None):
     if f.is_valid():
         product = f.save(commit=False)
         if not pk:
-            product.slug = slugify(f.cleaned_data['name'])
+            slug = slugify(f.cleaned_data['name'])
+            not_found = True
+            product.slug = slug
+            i = 2
+            while not_found:
+                try:
+                    _ = Product.objects.get(slug=product.slug)
+                except Product.DoesNotExist:
+                    break
+                product.slug = '{}-{}'.format(slug, i)
+                i += 1
+
             product.num_views = 0
-            product.in_date = datetime.datetime.now()
+            product.in_date = datetime.datetime.utcnow()
+
         if product.sold and not product.sold_date:
             product.sold = datetime.date.today()
 
